@@ -1,12 +1,12 @@
 #!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
+"""Tuya Open IOT HUB which base on MQTT."""
 
 import base64
 import json
 import time
 import threading
 import uuid
-
 from typing import Any, Callable, Dict
 from urllib.parse import urlsplit
 from paho.mqtt import client as mqtt
@@ -14,12 +14,16 @@ from Crypto.Cipher import AES
 
 from .openapi import TuyaOpenAPI
 from .project_type import ProjectType
+from .logging import logger
 
 LINK_ID = "tuya-iot-app-sdk-python.{}".format(uuid.uuid1())
 GCM_TAG_LENGTH = 16
+CONNECT_FAILED_NOT_AUTHORISED = 5
 
 
 class TuyaMQConfig:
+    """Tuya mqtt config."""
+
     url = ""
     client_id = ""
     username = ""
@@ -29,6 +33,7 @@ class TuyaMQConfig:
     expireTime = 0
 
     def __init__(self, mqConfigResponse: Dict[str, Any] = {}):
+        """Init TuyaMQConfig."""
         result = mqConfigResponse.get("result", {})
 
         self.url = result.get("url", "")
@@ -37,12 +42,11 @@ class TuyaMQConfig:
         self.password = result.get("password", "")
         self.source_topic = result.get("source_topic", {})
         self.sink_topic = result.get("sink_topic", {})
-        # self.expireTime = mqConfigResponse.get('t', 0) + result.get('expire_time', 0) * 1000
         self.expireTime = result.get("expire_time", 0)
 
 
 class TuyaOpenMQ(threading.Thread):
-    """Tuya open iot hub
+    """Tuya open iot hub.
 
     Tuya open iot hub base on mqtt.
 
@@ -51,6 +55,7 @@ class TuyaOpenMQ(threading.Thread):
     """
 
     def __init__(self, api: TuyaOpenAPI):
+        """Init TuyaOpenMQ."""
         threading.Thread.__init__(self)
         self.api: TuyaOpenAPI = api
         self._stop_event = threading.Event()
@@ -58,11 +63,10 @@ class TuyaOpenMQ(threading.Thread):
         self.message_listeners = set()
 
     def _get_mqtt_config(self) -> TuyaMQConfig:
-
         response = self.api.post(
             "/v1.0/iot-03/open-hub/access-config",
             {
-                "uid": self.api.tokenInfo.uid,
+                "uid": self.api.token_info.uid,
                 "link_id": LINK_ID,
                 "link_type": "mqtt",
                 "topics": "device",
@@ -77,7 +81,9 @@ class TuyaOpenMQ(threading.Thread):
 
         return TuyaMQConfig(response)
 
-    def _decode_mq_message(self, b64msg: str, password: str, t: str) -> Dict[str, Any]:
+    def _decode_mq_message(
+        self, b64msg: str, password: str, t: str
+    ) -> Dict[str, Any]:
         key = password[8:24]
 
         if self.api.project_type == ProjectType.SMART_HOME:
@@ -110,11 +116,24 @@ class TuyaOpenMQ(threading.Thread):
             )
             return json.loads(plaintext)
 
-    def _on_connect(self, mqttc: mqtt.Client, userData: Any, flags, rc):
-        print("[tuya-openmq] connected")
+    def _on_disconnect(self, client, userdata, rc):
+        if rc != 0:
+            logger.error(f"Unexpected disconnection.{rc}")
+        else:
+            logger.debug("disconnect")
 
-    def _on_message(self, mqttc: mqtt.Client, userData: Any, msg: mqtt.MQTTMessage):
-        print("[tuya-openmq] payload->", msg.payload)
+    def _on_connect(self, mqttc: mqtt.Client, userData: Any, flags, rc):
+        logger.debug(f"connect flags->{flags}, rc->{rc}")
+        if rc == 0:
+            for (key, value) in self.mq_config.source_topic.items():
+                mqttc.subscribe(value)
+        elif rc == CONNECT_FAILED_NOT_AUTHORISED:
+            self.__run_mqtt()
+
+    def _on_message(
+        self, mqttc: mqtt.Client, userData: Any, msg: mqtt.MQTTMessage
+    ):
+        logger.debug(f"payload-> {msg.payload}")
 
         msgDict = json.loads(msg.payload.decode("utf8"))
 
@@ -125,86 +144,91 @@ class TuyaOpenMQ(threading.Thread):
 
         t = msgDict.get("t", "")
 
-        mqConfig = userData["mqConfig"]
-        decryptedData = self._decode_mq_message(msgDict["data"], mqConfig.password, t)
+        mq_config = userData["mqConfig"]
+        decryptedData = self._decode_mq_message(
+            msgDict["data"], mq_config.password, t)
         if decryptedData is None:
             return
 
         msgDict["data"] = decryptedData
-        print("[tuya-openmq] on_message: {}".format(msgDict))
+        logger.debug(f"on_message: {msgDict}")
 
         for listener in self.message_listeners:
             listener(msgDict)
 
-    def _on_subscribe(self, mqttc: mqtt.Client, userData: Any, mid, granted_qos):
-        # print("[tuya-openmq] _on_subscribe: {}".format(mid))
-        pass
+    def _on_subscribe(
+        self, mqttc: mqtt.Client, userData: Any, mid, granted_qos
+    ):
+        logger.debug(f"_on_subscribe: {mid}")
 
     def _on_log(self, mqttc: mqtt.Client, userData: Any, level, string):
-        # print("[tuya-openmq] _on_log: {}".format(string))
-        pass
+        logger.debug(f"_on_log: {string}")
 
     def run(self):
+        """Method representing the thread's activity which should not be used directly."""
         while not self._stop_event.is_set():
-            mqConfig = self._get_mqtt_config()
-            if mqConfig is None:
-                print("[tuya-openmq] error while get mqtt config")
-                break
-
-            print("[tuya-openmq] connecting {}".format(mqConfig.url))
-            mqttc = self._start(mqConfig)
-
-            if self.client:
-                self.client.disconnect()
-            self.client = mqttc
+            self.__run_mqtt()
 
             # reconnect every 2 hours required.
-            time.sleep(mqConfig.expireTime - 60)
+            time.sleep(self.mq_config.expireTime - 60)
 
-    def _start(self, mqConfig: TuyaMQConfig) -> mqtt.Client:
-        mqttc = mqtt.Client(mqConfig.client_id)
-        mqttc.username_pw_set(mqConfig.username, mqConfig.password)
-        mqttc.user_data_set({"mqConfig": mqConfig})
+    def __run_mqtt(self):
+        mq_config = self._get_mqtt_config()
+        if mq_config is None:
+            logger.error("error while get mqtt config")
+            return
+
+        self.mq_config = mq_config
+
+        logger.debug(f"connecting {mq_config.url}")
+        mqttc = self._start(mq_config)
+
+        if self.client:
+            self.client.disconnect()
+        self.client = mqttc
+
+    def _start(self, mq_config: TuyaMQConfig) -> mqtt.Client:
+        mqttc = mqtt.Client(mq_config.client_id)
+        mqttc.username_pw_set(mq_config.username, mq_config.password)
+        mqttc.user_data_set({"mqConfig": mq_config})
         mqttc.on_connect = self._on_connect
         mqttc.on_message = self._on_message
         mqttc.on_subscribe = self._on_subscribe
         mqttc.on_log = self._on_log
+        mqttc.on_disconnect = self._on_disconnect
 
-        url = urlsplit(mqConfig.url)
+        url = urlsplit(mq_config.url)
         if url.scheme == "ssl":
             mqttc.tls_set()
 
         mqttc.connect(url.hostname, url.port)
-        for (key, value) in mqConfig.source_topic.items():
-            mqttc.subscribe(value)
 
         mqttc.loop_start()
         return mqttc
 
     def start(self):
-        """Start mqtt
+        """Start mqtt.
 
         Start mqtt thread
         """
-        print("[tuya-openmq] start")
+        logger.debug("start")
         super().start()
 
     def stop(self):
-        """Stop mqtt
+        """Stop mqtt.
 
         Stop mqtt thread
         """
-        print("[tuya-openmq] stop")
+        logger.debug("stop")
         self.message_listeners = set()
         self.client.disconnect()
         self.client = None
         self._stop_event.set()
 
     def add_message_listener(self, listener: Callable[[str], None]):
-        """Add mqtt message listener"""
-        print("add listener", listener)
+        """Add mqtt message listener."""
         self.message_listeners.add(listener)
 
     def remove_message_listener(self, listener: Callable[[str], None]):
-        """Remvoe mqtt message listener"""
+        """Remvoe mqtt message listener."""
         self.message_listeners.discard(listener)
